#!/bin/sh

i=0
while [ $i -lt 16 ]; do
 i=`expr $i + 1`
 echo cp -f left_ptr_watch`expr 17 - $i`.png temp.png;
 echo cp -f left_ptr_watch$i.png left_ptr_watch`expr 17 - $i`;
 echo cp -f temp.png  left_ptr_watch$i.png;
 echo rm -f temp.png;
done
 
