#!/bin/sh
version=`kdialog --combobox "Which version of CrystalCursors you want to use?"  blue blue_classic blue_noanim gray gray_noanim green green_classic green_noanim white white_noanim`

case $version in
 blue|blue_classic|blue_noanim|gray|gray_noanim|green|green_classic|green_noanim|white|white_noanim)
 echo "[Icon Theme]" > ~/.icons/default/index.theme
 echo "Inherits = crystal$version" >> ~/.icons/default/index.theme
kdialog --msgbox "Cursors changed: only the new started apps would be affected.";;
esac
